@@ -2,42 +2,6 @@ from enum import Enum, IntEnum
 
 from gitlab._version import __title__, __version__
 
-# NOTE(jlvillal): '_DEPRECATED' only affects users accessing constants via the
-# top-level gitlab.* namespace. See 'gitlab/__init__.py:__getattr__()' for the
-# consumer of '_DEPRECATED' For example 'x = gitlab.NO_ACCESS'.  We want users
-# to instead use constants by doing code like: gitlab.const.NO_ACCESS.
-_DEPRECATED = [
-    "ADMIN_ACCESS",
-    "DEFAULT_URL",
-    "DEVELOPER_ACCESS",
-    "GUEST_ACCESS",
-    "MAINTAINER_ACCESS",
-    "MINIMAL_ACCESS",
-    "NO_ACCESS",
-    "NOTIFICATION_LEVEL_CUSTOM",
-    "NOTIFICATION_LEVEL_DISABLED",
-    "NOTIFICATION_LEVEL_GLOBAL",
-    "NOTIFICATION_LEVEL_MENTION",
-    "NOTIFICATION_LEVEL_PARTICIPATING",
-    "NOTIFICATION_LEVEL_WATCH",
-    "OWNER_ACCESS",
-    "REPORTER_ACCESS",
-    "SEARCH_SCOPE_BLOBS",
-    "SEARCH_SCOPE_COMMITS",
-    "SEARCH_SCOPE_GLOBAL_SNIPPET_TITLES",
-    "SEARCH_SCOPE_ISSUES",
-    "SEARCH_SCOPE_MERGE_REQUESTS",
-    "SEARCH_SCOPE_MILESTONES",
-    "SEARCH_SCOPE_PROJECT_NOTES",
-    "SEARCH_SCOPE_PROJECTS",
-    "SEARCH_SCOPE_USERS",
-    "SEARCH_SCOPE_WIKI_BLOBS",
-    "USER_AGENT",
-    "VISIBILITY_INTERNAL",
-    "VISIBILITY_PRIVATE",
-    "VISIBILITY_PUBLIC",
-]
-
 
 class GitlabEnum(str, Enum):
     """An enum mixed in with str to make it JSON-serializable."""
@@ -90,6 +54,24 @@ class SearchScope(GitlabEnum):
     PROJECT_NOTES: str = "notes"
 
 
+# https://docs.gitlab.com/ee/api/merge_requests.html#merge-status
+class DetailedMergeStatus(GitlabEnum):
+    # possible values for the detailed_merge_status field of Merge Requests
+    BLOCKED_STATUS: str = "blocked_status"
+    BROKEN_STATUS: str = "broken_status"
+    CHECKING: str = "checking"
+    UNCHECKED: str = "unchecked"
+    CI_MUST_PASS: str = "ci_must_pass"
+    CI_STILL_RUNNING: str = "ci_still_running"
+    DISCUSSIONS_NOT_RESOLVED: str = "discussions_not_resolved"
+    DRAFT_STATUS: str = "draft_status"
+    EXTERNAL_STATUS_CHECKS: str = "external_status_checks"
+    MERGEABLE: str = "mergeable"
+    NOT_APPROVED: str = "not_approved"
+    NOT_OPEN: str = "not_open"
+    POLICIES_DENIED: str = "policies_denied"
+
+
 DEFAULT_URL: str = "https://gitlab.com"
 
 NO_ACCESS = AccessLevel.NO_ACCESS.value
@@ -131,6 +113,7 @@ SEARCH_SCOPE_PROJECT_NOTES = SearchScope.PROJECT_NOTES.value
 
 USER_AGENT: str = f"{__title__}/{__version__}"
 
+NO_JSON_RESPONSE_CODES = [204]
 RETRYABLE_TRANSIENT_ERROR_CODES = [500, 502, 503, 504] + list(range(520, 531))
 
 __all__ = [
@@ -138,5 +121,33 @@ __all__ = [
     "Visibility",
     "NotificationLevel",
     "SearchScope",
+    "ADMIN_ACCESS",
+    "DEFAULT_URL",
+    "DEVELOPER_ACCESS",
+    "GUEST_ACCESS",
+    "MAINTAINER_ACCESS",
+    "MINIMAL_ACCESS",
+    "NO_ACCESS",
+    "NOTIFICATION_LEVEL_CUSTOM",
+    "NOTIFICATION_LEVEL_DISABLED",
+    "NOTIFICATION_LEVEL_GLOBAL",
+    "NOTIFICATION_LEVEL_MENTION",
+    "NOTIFICATION_LEVEL_PARTICIPATING",
+    "NOTIFICATION_LEVEL_WATCH",
+    "OWNER_ACCESS",
+    "REPORTER_ACCESS",
+    "SEARCH_SCOPE_BLOBS",
+    "SEARCH_SCOPE_COMMITS",
+    "SEARCH_SCOPE_GLOBAL_SNIPPET_TITLES",
+    "SEARCH_SCOPE_ISSUES",
+    "SEARCH_SCOPE_MERGE_REQUESTS",
+    "SEARCH_SCOPE_MILESTONES",
+    "SEARCH_SCOPE_PROJECT_NOTES",
+    "SEARCH_SCOPE_PROJECTS",
+    "SEARCH_SCOPE_USERS",
+    "SEARCH_SCOPE_WIKI_BLOBS",
+    "USER_AGENT",
+    "VISIBILITY_INTERNAL",
+    "VISIBILITY_PRIVATE",
+    "VISIBILITY_PUBLIC",
 ]
-__all__.extend(_DEPRECATED)
